pub fn extract_mview(
file_path: &Path,
output_dir: &Path,
create_subdir: bool,
) -> Result<()>Expand description
Extracts the contents of an .mview file to the specified output directory.
Arguments
file_path- The path to the .mview file to extract.output_dir- The directory to extract the contents to.create_subdir- Whether to create a subdirectory for the extracted contents.
Errors
This function will return an error if the file cannot be opened, read, or written to the output directory.
Panics
This function will panic if the file stem cannot be determined from the file path.